==> OpenXOPS-tags_v1.020-20150628-r97.tar.gz: OpenXOPS-tags_v1.020-20150628-r97/v1.020-20150628/objectmanager.h <==
//! @file objectmanager.h
//! @brief ObjectManagerNX̐錾

//--------------------------------------------------------------------------------
// 
// OpenXOPS
// Copyright (c) 2014-2015, OpenXOPS Project / [-_-;](mikan) All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// * Redistributions of source code must retain the above copyright notice, 
//   this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright notice, 
//   this list of conditions and the following disclaimer in the documentation 
//   and/or other materials provided with the distribution.
// * Neither the name of the OpenXOPS Project nor the@names of its contributors 
//   may be used to endorse or promote products derived from this software 
//   without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL OpenXOPS Project BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//--------------------------------------------------------------------------------

#ifndef OBJECTMANAGER_H
#define OBJECTMANAGER_H

#define MAX_HUMAN 96			//!< ől@yxzFAIx̊֌We24̔{fɂ邱ƁI
#define MAX_WEAPON 200			//!< ̍ő吔
#define MAX_SMALLOBJECT 40		//!< ̍ő吔

#define MAX_BULLET 128			//!< ee̍ő吔
#define MAX_GRENADE 32			//!< ֒e̍ő吔
#define MAX_EFFECT 256			//!< GtFNg̍ő吔

#define WEAPONSHOT_HEIGHT (VIEW_HEIGHT)	//!< e𔭎˂鍂

#define TOTAL_WEAPON_AUTOBULLET 3	//!< ɎIɕĂ񂳂eiẻ{j

#define HUMAN_BULLETCOLLISION_HEAD_H 2.8f	//!< ̓蔻̍
#define HUMAN_BULLETCOLLISION_HEAD_R 1.3f	//!< ̓蔻̔a
#define HUMAN_BULLETCOLLISION_UP_H 7.5f		//!< 㔼g̓蔻̍
#define HUMAN_BULLETCOLLISION_UP_R 2.5f		//!< 㔼g̓蔻̔a
#define HUMAN_BULLETCOLLISION_LEG_H 10.0f	//!< ̓蔻̍
#define HUMAN_BULLETCOLLISION_LEG_R 2.5f	//!< ̓蔻̔a

#define SMALLOBJECT_SCALE 0.13f	//!< 蔻̔{

#ifndef H_LAYERLEVEL
 #define H_LAYERLEVEL 3		//!< Select include file.
#endif
#include "main.h"

//! GtFNg`vZp\
struct effectdata{
	int id;		//!< f[^ԍ
	float dist;	//!< 
};

//! @brief IuWFNgǗNX
//! @details eIuWFNg̏EvZE`ȂǂsǗ܂B
class ObjectManager
{
	class human *HumanIndex;					//!< lIuWFNg
	class weapon *WeaponIndex;					//!< IuWFNg
	class smallobject *SmallObjectIndex;		//!< IuWFNg
	class bullet *BulletIndex;					//!< eIuWFNg
	class grenade *GrenadeIndex;				//!< ֒eIuWFNg
	class effect *EffectIndex;				//!< ֒eIuWFNg

	unsigned int framecnt;		//!< t[̃JEg

	int *Human_ontarget;	//!< 
	int *Human_kill;		//!< |G̐
	int *Human_headshot;	//!< G̓ɖ
	bool *Human_ShotFlag;	//!< CtOi}YtbVpj

	bool FriendlyFire;		//!< FFimjL

	int Player_HumanID;		//!< vC[삷lIuWFNgID

	int AddHumanIndex_TextureID;		//!< Oǂݍ񂾃eNX`ID

	ParameterInfo *GameParamInfo;		//!< Q[̐ݒl
	D3DGraphics *d3dg;					//!< `NX
	ResourceManager *Resource;			//!< \[XǗ
	BlockDataInterface *BlockData;		//!< ubNf[^ǗNX
	PointDataInterface *PointData;		//!< |Cgf[^ǗNX
	Collision *CollD;					//!< 蔻ǗNX
	SoundManager *GameSound;				//!< Q[ʉǗNX
	MIFInterface *MIFdata;				//!< MIFRg[NX

	int AddHumanIndex(pointdata data, pointdata infodata);
	int AddWeaponIndex(pointdata data);
	int AddSmallObjectIndex(pointdata data);
	void SetHumanBlood(float x, float y, float z);
	bool CollideHuman(human *in_humanA, human *in_humanB);
	bool CollideBullet(bullet *in_bullet);
	void HitBulletMap(float x, float y, float z);
	void HitBulletHuman(int HitHuman_id, int Hit_id, float x, float y, float z, float brx, int attacks, int humanid);
	void HitBulletSmallObject(int HitSmallObject_id, float x, float y, float z, int attacks);
	bool GrenadeExplosion(grenade *in_grenade);
	void DeadEffect(human *in_human);
	bool CollideBlood(effect *in_effect, int *id, int *face, float *pos_x, float *pos_y, float *pos_z);
	void PickupWeapon(human *in_human, weapon *in_weapon);
	void CleanupPointDataToObject();
	int SortEffect(float camera_x, float camera_y, float camera_z, effectdata data[]);
	void ShotWeaponEffect(int humanid);

public:
	ObjectManager();
	~ObjectManager();
	void SetClass(ParameterInfo *in_GameParamInfo, D3DGraphics *in_d3dg, ResourceManager *in_Resource, BlockDataInterface *in_BlockData, PointDataInterface *in_PointData, Collision *in_CollD, SoundManager *in_GameSound, MIFInterface *in_MIFdata);
	int AddHumanIndex(float px, float py, float pz, float rx, int CharacterID, int TeamID, int WeaponID[]);
	int AddVisualWeaponIndex(int WeaponID, bool loadbullet);
	int AddSmallObjectIndex(float px, float py, float pz, float rx, int paramID, bool MapColl);
	int AddEffect(float pos_x, float pos_y, float pos_z, float move_x, float move_y, float move_z, float size, float rotation, int count, int texture, int settype);
	int AddMapEffect(int id, int face, float pos_x, float pos_y, float pos_z, float size, float rotation, int count, int texture);
	void LoadPointData();
	bool GetFriendlyFireFlag();
	void SetFriendlyFireFlag(bool flag);
	int GetPlayerID();
	void SetPlayerID(int id);
	human* GeHumanObject(int id);
	human* GetPlayerHumanObject();
	weapon* GetWeaponObject(int id);
	smallobject* GetSmallObject(int id);
	bullet* GetBulletObject(int id);
	bullet* GetNewBulletObject();
	grenade* GetNewGrenadeObject();
	human* SearchHuman(signed char p4);
	smallobject* SearchSmallobject(signed char p4);
	void MoveForward(int human_id);
	void MoveBack(int human_id);
	void MoveLeft(int human_id);
	void MoveRight(int human_id);
	void MoveWalk(int human_id);
	void MoveJump(int human_id);
	int ShotWeapon(int human_id);
	void ReloadWeapon(int human_id);
	void ChangeWeapon(int human_id, int id = -1);
	bool DumpWeapon(int human_id);
	void ChangeScopeMode(int human_id);
	int ChangeShotMode(int human_id);
	bool CheatAddBullet(int human_id);
	bool CheatNewWeapon(int human_id, int new_weaponID);
	bool CheckZombieAttack(human* MyHuman, human* EnemyHuman);
	void HitZombieAttack(human* EnemyHuman);
	bool HumanResuscitation(int id);
	int CheckGameOverorComplete();
	bool GetObjectInfoTag(float camera_x, float camera_y, float camera_z, float camera_rx, float camera_ry, int *color, char *infostr);
	int Process(int cmdF5id, bool demomode, float camera_rx, float camera_ry);
	bool GetHumanShotInfo(int id, int *ontarget, int *kill, int *headshot);
	void Render(float camera_x, float camera_y, float camera_z, int HidePlayer);
	void Cleanup();
};

#endif

==> OpenXOPS-tags_v1.030-20160111-r189.tar.gz: OpenXOPS-tags_v1.030-20160111-r189/v1.030-20160111/objectmanager.h <==
//! @file objectmanager.h
//! @brief ObjectManagerNX̐錾

//--------------------------------------------------------------------------------
// 
// OpenXOPS
// Copyright (c) 2014-2016, OpenXOPS Project / [-_-;](mikan) All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// * Redistributions of source code must retain the above copyright notice, 
//   this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright notice, 
//   this list of conditions and the following disclaimer in the documentation 
//   and/or other materials provided with the distribution.
// * Neither the name of the OpenXOPS Project nor the names of its contributors 
//   may be used to endorse or promote products derived from this software 
//   without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL OpenXOPS Project BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//--------------------------------------------------------------------------------

#ifndef OBJECTMANAGER_H
#define OBJECTMANAGER_H

#define MAX_HUMAN 96			//!< ől@yxzFAIx̊֌We24̔{fɂ邱ƁI
#define MAX_WEAPON 200			//!< ̍ő吔
#define MAX_SMALLOBJECT 40		//!< ̍ő吔

#define MAX_BULLET 128			//!< ee̍ő吔
#define MAX_GRENADE 32			//!< ֒e̍ő吔
#define MAX_EFFECT 256			//!< GtFNg̍ő吔

#define SMALLOBJECT_SCALE 5.0f				//!< ̕\{
#define BULLET_SCALE 1.0f				//!< ee̕\{

#define WEAPONSHOT_HEIGHT (VIEW_HEIGHT)	//!< e𔭎˂鍂

#define TOTAL_WEAPON_AUTOBULLET 3	//!< ɎIɕĂ񂳂eiẻ{j

#define HUMAN_BULLETCOLLISION_HEAD_H 2.8f	//!< ̓蔻̍
#define HUMAN_BULLETCOLLISION_HEAD_R 1.3f	//!< ̓蔻̔a
#define HUMAN_BULLETCOLLISION_UP_H 7.5f		//!< 㔼g̓蔻̍
#define HUMAN_BULLETCOLLISION_UP_R 2.5f		//!< 㔼g̓蔻̔a
#define HUMAN_BULLETCOLLISION_LEG_H 10.0f	//!< ̓蔻̍
#define HUMAN_BULLETCOLLISION_LEG_R 2.5f	//!< ̓蔻̔a

#define SMALLOBJECT_COLLISIONSCALE 0.13f	//!< 蔻̔{

#ifndef H_LAYERLEVEL
 #define H_LAYERLEVEL 3		//!< Select include file.
#endif
#include "main.h"

//! GtFNg`vZp\
struct effectdata{
	int id;		//!< f[^ԍ
	float dist;	//!< 
};

//! @brief IuWFNgǗNX
//! @details eIuWFNg̏EvZE`ȂǂsǗ܂B
class ObjectManager
{
	class human *HumanIndex;					//!< lIuWFNg
	class weapon *WeaponIndex;					//!< IuWFNg
	class smallobject *SmallObjectIndex;		//!< IuWFNg
	class bullet *BulletIndex;					//!< eIuWFNg
	class grenade *GrenadeIndex;				//!< ֒eIuWFNg
	class effect *EffectIndex;				//!< ֒eIuWFNg

	unsigned int framecnt;		//!< t[̃JEg

	int *Human_ontarget;	//!< 
	int *Human_kill;		//!< |G̐
	int *Human_headshot;	//!< G̓ɖ
	bool *Human_ShotFlag;	//!< CtOi}YtbVpj

	bool FriendlyFire;		//!< FFimjL

	int Player_HumanID;		//!< vC[삷lIuWFNgID

	int AddHumanIndex_TextureID;		//!< Oǂݍ񂾃eNX`ID

	ParameterInfo *GameParamInfo;		//!< Q[̐ݒl
	D3DGraphics *d3dg;					//!< `NX
	ResourceManager *Resource;			//!< \[XǗ
	BlockDataInterface *BlockData;		//!< ubNf[^ǗNX
	PointDataInterface *PointData;		//!< |Cgf[^ǗNX
	Collision *CollD;					//!< 蔻ǗNX
	SoundManager *GameSound;				//!< Q[ʉǗNX
	MIFInterface *MIFdata;				//!< MIFRg[NX

	int AddHumanIndex(pointdata data, pointdata infodata);
	int AddWeaponIndex(pointdata data);
	int AddSmallObjectIndex(pointdata data);
	void SetHumanBlood(float x, float y, float z, int damage);
	bool CollideHuman(human *in_humanA, human *in_humanB);
	bool CollideBullet(bullet *in_bullet);
	void HitBulletMap(float x, float y, float z);
	void HitBulletHuman(int HitHuman_id, int Hit_id, float x, float y, float z, float brx, int attacks, int humanid);
	void HitBulletSmallObject(int HitSmallObject_id, float x, float y, float z, int attacks);
	bool GrenadeExplosion(grenade *in_grenade);
	void DeadEffect(human *in_human);
	bool CollideBlood(effect *in_effect, int *id, int *face, float *pos_x, float *pos_y, float *pos_z);
	void PickupWeapon(human *in_human, weapon *in_weapon);
	void CleanupPointDataToObject();
	int SortEffect(float camera_x, float camera_y, float camera_z, effectdata data[]);
	void ShotWeaponEffect(int humanid);

public:
	ObjectManager();
	~ObjectManager();
	void SetClass(ParameterInfo *in_GameParamInfo, D3DGraphics *in_d3dg, ResourceManager *in_Resource, BlockDataInterface *in_BlockData, PointDataInterface *in_PointData, Collision *in_CollD, SoundManager *in_GameSound, MIFInterface *in_MIFdata);
	int AddHumanIndex(float px, float py, float pz, float rx, int CharacterID, int TeamID, int WeaponID[]);
	int AddVisualWeaponIndex(int WeaponID, bool loadbullet);
	int AddSmallObjectIndex(float px, float py, float pz, float rx, int paramID, bool MapColl);
	int AddEffect(float pos_x, float pos_y, float pos_z, float move_x, float move_y, float move_z, float size, float rotation, int count, int texture, int settype);
	int AddMapEffect(int id, int face, float pos_x, float pos_y, float pos_z, float size, float rotation, int count, int texture);
	void LoadPointData();
	void Recovery();
	bool GetFriendlyFireFlag();
	void SetFriendlyFireFlag(bool flag);
	int GetPlayerID();
	void SetPlayerID(int id);
	human* GeHumanObject(int id);
	human* GetPlayerHumanObject();
	weapon* GetWeaponObject(int id);
	smallobject* GetSmallObject(int id);
	bullet* GetBulletObject(int id);
	bullet* GetNewBulletObject();
	grenade* GetNewGrenadeObject();
	human* SearchHuman(signed char p4);
	smallobject* SearchSmallobject(signed char p4);
	void MoveForward(int human_id);
	void MoveBack(int human_id);
	void MoveLeft(int human_id);
	void MoveRight(int human_id);
	void MoveWalk(int human_id);
	void MoveJump(int human_id);
	int ShotWeapon(int human_id);
	void ReloadWeapon(int human_id);
	void ChangeWeapon(int human_id, int id = -1);
	bool DumpWeapon(int human_id);
	void ChangeScopeMode(int human_id);
	int ChangeShotMode(int human_id);
	bool CheatAddBullet(int human_id);
	bool CheatNewWeapon(int human_id, int new_weaponID);
	bool CheckZombieAttack(human* MyHuman, human* EnemyHuman);
	void HitZombieAttack(human* EnemyHuman);
	bool HumanResuscitation(int id);
	int CheckGameOverorComplete();
	bool GetObjectInfoTag(float camera_x, float camera_y, float camera_z, float camera_rx, float camera_ry, int *color, char *infostr);
	int Process(int cmdF5id, bool demomode, float camera_rx, float camera_ry);
	bool GetHumanShotInfo(int id, int *ontarget, int *kill, int *headshot);
	void Render(float camera_x, float camera_y, float camera_z, int HidePlayer);
	void Cleanup();
};

#endif
